indexing
	description: "Constants supporting calendars and date calculations"
	license: "Eiffel Forum License v2 - See license.txt"
	source: "{
		Amalasoft Corporation
		273 Harwood Avenue
		Littleton, MA 01460 USA
		}"
	status: "Copyright 1995-2008, Amalasoft"
	date: "$Date: 2008/04/26 $"
	revision: "$Revision: 002$"

class AEL_DATE_TIME_CONSTANTS

inherit
	AEL_DATE_TIME_NAMES

feature -- Constants

	K_thursday: INTEGER is 4	-- for Julian reformation
	K_saturday: INTEGER is 6	-- 1 Jan 1 was a Saturday

	K_first_missing_day: INTEGER is 639787	-- 3 Sep 1752
	K_number_missing_days: INTEGER is 11		-- 11 day correction

	K_maxdays: INTEGER is 43
	K_space: INTEGER is -1

	K_day_len: INTEGER is 3		-- 3 spaces per day */
	K_j_day_len: INTEGER is 4		-- 4 spaces per day */
	K_week_len: INTEGER is 21		-- 7 days * 3 characters */
	K_j_week_len: INTEGER is 28		-- 7 days * 4 characters */
	K_head_sep: INTEGER is 2		-- spaces between day headings */
	K_j_head_sep: INTEGER is 2

	K_max_weeks_per_month: INTEGER is 6

	K_range_tu_nanosecond: INTEGER_INTERVAL is
		once
			create Result.make (0, 999)
		end

	K_range_tu_microsecond: INTEGER_INTERVAL is
		once
			create Result.make (0, 999)
		end

	K_range_tu_millisecond: INTEGER_INTERVAL is
		once
			create Result.make (0, 999)
		end

	K_range_tu_second: INTEGER_INTERVAL is
		once
			create Result.make (0, 59)
		end

	K_range_tu_minute: INTEGER_INTERVAL is
		once
			create Result.make (0, 59)
		end

	K_range_tu_hour: INTEGER_INTERVAL is
		once
			create Result.make (0, 23)
		end

	K_range_tu_month: INTEGER_INTERVAL is
		once
			create Result.make (1, 12)
		end

	K_range_tu_week: INTEGER_INTERVAL is
		once
			create Result.make (1, 7)
		end

	K_range_tu_year: INTEGER_INTERVAL is
		once
			create Result.make (0, 2037)
		end

	K_time_unit_nanosecond: INTEGER is -5
	K_time_unit_microsecond: INTEGER is -4
	K_time_unit_millisecond: INTEGER is -3
			-- reserve -1, -2 for 1/10 and 1/100 of second
	K_time_unit_second: INTEGER is 0
	K_time_unit_minute: INTEGER is 1
	K_time_unit_hour: INTEGER is 2
	K_time_unit_day: INTEGER is 3
	K_time_unit_week: INTEGER is 4
	K_time_unit_month: INTEGER is 5
	K_time_unit_year: INTEGER is 6

	K_seconds_per_minute: INTEGER is 60
	K_minutes_per_hour: INTEGER is 60
	K_hours_per_day: INTEGER is 24
			-- not true at DST changeover
	K_days_per_week: INTEGER is 7
	K_min_days_per_month: INTEGER is 28
	K_max_days_per_month: INTEGER is 31
	K_weeks_per_year: INTEGER is 52
	K_months_per_year: INTEGER is 12
	K_min_days_per_year: INTEGER is 365
	K_max_days_per_year: INTEGER is 366

	K_seconds_per_hour: INTEGER is
		once
			Result := K_seconds_per_minute * K_minutes_per_hour
		end

	K_seconds_per_day: INTEGER is
			-- Typical number of seconds per day
			-- Does NOT consider DST transitions (23 and 25 your days)
		once
			Result := 60 * 60 * 24
		end

	K_seconds_per_week: INTEGER is
			-- Typical number of seconds per week
			-- Does NOT consider DST transitions (23 and 25 your days)
		once
			Result := K_seconds_per_day * 7
		end

	days_in_month_table: ARRAY [ INTEGER ] is
			-- The first 12 elements are non-leap year values,
			-- the second 12 elements are leap-year values
		once
			Result := << 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31,
			             31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
							 >>
		end

end -- class AEL_DATE_TIME_CONSTANTS
